@@ -16,14 +16,51 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-#define AB_ZUGL		512	/*  Laenge der Zugliste pro Zug		*/
-#define AB_ZUG_S	256	/*  Beginn der Schlagzuege in Zugliste	*/
-#define NONE		0	/*  None to move			*/
+#ifndef _MAKROS_H_
+#define _MAKROS_H_
+
+#include <glib.h>
+
+#ifdef __cplusplus
+extern "C" {
+#pragma }
+#endif /* __cplusplus */
+
+/* Types */
+typedef gushort Square;
+typedef gchar   Piece;
+
+/* Various empty defines */
+#define NONE		0
+
+/* Generated movelist */
+#define AB_ZUGL		512	/*  Length of list generated moves	*/
+#define AB_ZUG_S	256	/*  Beginning of generated capture moves*/
+
+/* Colours */
 #define WHITE		1	/*  White to Move			*/
 #define BLACK		129	/*  Black to move			*/
+
+/* Notation types */
 #define	SAN		0	/*  Standard algebraic notation		*/
 #define	COORD		1	/*  Coordinate notation			*/
 
+/* Game results */
+#define	GAME_NONE	0	/*  No game			        */
+#define	GAME_PAUSED	1	/*  Game is paused			*/
+#define	GAME_PROGRESS	2	/*  Game is in progress			*/
+#define	GAME_ABORTED	3	/*  Game was aborted			*/
+#define	GAME_WHITE	4	/*  White won the game			*/
+#define	GAME_BLACK	5	/*  Black won the game			*/
+#define	GAME_DRAW	6	/*  Draw			        */
+
+/* Board window modes */
+#define	COMPUTER_BLACK	1
+#define	COMPUTER_WHITE	2
+#define	AUTOPLAY	3
+#define	ANALYSE		4
+#define	HUMANS		5
+
 #define PIECE_SIZE 40
 
 #define  OL            9     /********************************************/
@@ -48,26 +85,26 @@
 /*                                                                       */
 /*************************************************************************/
 
-#define WP		33	 /*  white pawn      weisser bauer            */
-#define WN		34	 /*  white knight      weisser springer            */
-#define WB		35	 /*  white bishop      weisser laufer            */
-#define WR		36	 /*  white rook      weisser turm            */
-#define WQ		37	 /*  white queen      weisser dame            */
-#define WK		38	 /*  white king      weisser koenig            */
-#define BP		65	 /*  black pawn      schwarzer bauer            */
-#define BN		66	 /*  black knight      schwarzer springer            */
-#define BB		67	 /*  black bishop      schwarzer laufer            */
-#define BR		68	 /*  black rook      schwarzer turm            */
-#define BQ		69	 /*  black queen      schwarzer dame            */
-#define BK		70	/*  black King		schwarzer koenig            */
-#define EMPTY     0          /*  emptry						leer            */
-#define BORDER    16          /*  border (illegal )       Rand             */
+#define WP		33	 /*  white pawn   */
+#define WN		34	 /*  white knight */
+#define WB		35	 /*  white bishop */
+#define WR		36	 /*  white rook   */
+#define WQ		37	 /*  white queen  */
+#define WK		38	 /*  white king   */
+#define BP		65	 /*  black pawn   */
+#define BN		66	 /*  black knight */
+#define BB		67	 /*  black bishop */
+#define BR		68	 /*  black rook   */
+#define BQ		69	 /*  black queen  */
+#define BK		70	 /*  black king	  */
+#define EMPTY     0              /*  empty	  */
+#define BORDER    16             /*  border (illegal) */
 
-#define WPIECE(c) ( (c) & 32 )   /* white piece? */
-#define BPIECE(c) ( (c) & 64 )   /* black piece? */
+#define WPIECE(c) ((c) & 32)   /* white piece? */
+#define BPIECE(c) ((c) & 64)   /* black piece? */
 
 /****************************************************************/
-/*                      Felder    Squares                      */
+/*                      Squares                                 */
 /****************************************************************/
 
 #define A1 21
@@ -135,3 +172,9 @@
 #define G8 97
 #define H8 98
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+#endif /* _MAKROS_H_ */
+
