@@ -21,6 +21,7 @@
  * Author: Robert Wilhelm
  */
 
+#include <config.h>
 #include <gnome.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include "debug.h"
@@ -30,9 +31,9 @@
 #include "movlist.h"
 
 typedef struct {
-	char piece;
-	char from;
-	char to;
+	Piece piece;
+	Square from;
+	Square to;
 	int  check : 1;
 	int  mate  : 1;
 	int  take  : 1;
@@ -128,7 +129,7 @@ init (MoveList *movelist)
 {
 	MoveListPrivate *priv;
 	GtkWidget *clist, *hbox;
-	static char *titles[] ={ _("Number"), _("White"), _("Black")};
+	static char *titles[] ={ N_("Number"), N_("White"), N_("Black")};
 	const gchar *fn[] = {"start.png", "prev.png", "next.png", "end.png"};
 	const gpointer cb[] = {ml_clicked_start, ml_clicked_prev, ml_clicked_next, ml_clicked_end};
 	
@@ -148,6 +149,8 @@ init (MoveList *movelist)
 	gtk_widget_show (priv->swindow);
 
 	/* The list of moves */
+	for (i = 0; i < 3; i++)
+		titles[i] = _(titles[i]);
 	clist = gtk_clist_new_with_titles (3, titles);
 	gtk_clist_set_selection_mode (GTK_CLIST (clist), GTK_SELECTION_BROWSE);
 	gtk_clist_column_titles_passive (GTK_CLIST (clist));
@@ -291,7 +294,7 @@ move_list_get_position_current (MoveList *movelist)
 }
 
 void
-move_list_get_ply (MoveList *movelist, gint plynum, gint *from, gint *to)
+move_list_get_ply (MoveList *movelist, gint plynum, Square *from, Square *to)
 {
 	MoveListPrivate *priv;
 	Move *mv;
@@ -344,7 +347,7 @@ move_list_addtolist (MoveList *movelist)
 }
 
 void
-move_list_add (MoveList *movelist, int from, int to)
+move_list_add (MoveList *movelist, Square from, Square to)
 {
 	MoveListPrivate *priv;
 	Position *currpos;
@@ -374,7 +377,7 @@ move_list_add (MoveList *movelist, int from, int to)
 	if (prefs_get_notation () == SAN) {
 		str = move_to_san (p->pos, p->from, p->to);
 		strcpy (p->ascii, str);
-		free (str);
+		g_free (str);
 	} else {
 		piece_move_to_ascii (p->ascii, p->piece, p->from, p->to);
 	}
